@@ -95,16 +95,12 @@ class Photo(object):
 
     def set_title(self):
         """Find title (IPTC Object Name)"""
-        origlink = u"<a href=\"original/%s\">haute rés.</a>" \
-                    % self.filename
+        pass
         #proc = Popen(["iptc", "-p", "2:005", self.filepath],
         #             stdout=PIPE, stderr=STDOUT)
         #output = proc.communicate()[0]
         #if proc.returncode == 0:
         #    self.title = u"%s (%s)" % (output.strip(), origlink)
-        #else:
-        #    self.title = origlink
-        self.title = origlink
 
 
     def resize(self, resized_dir):
@@ -120,7 +116,7 @@ class Photo(object):
             outim = im.resize((new_width, new_height), PIL.Image.ANTIALIAS)
             outim.save(resized_path, quality=90)
         else:
-            tmpfd, tmpfile = tempfile.mkstemp(".jpg")
+            tmpfd, tmpfile = tempfile.mkstemp(".jpg", prefix="webstag-")
             os.close(tmpfd)
             if self.height > IMG_SIZE["height"]:
                 call(["convert", "-resize", "x%s" % IMG_SIZE["height"],
