@@ -10,6 +10,10 @@ $(function() {
         },
         onClosed: function() {
             window.location.hash = 'all';
+        },
+        title: function() {
+            var full_url = $(this).attr('data-full');
+            return '<a href="' + full_url + '" target="_blank">HD</a>';
         }
     }
 
